@@ -1,5 +1,6 @@
-__version__ = '2.0.1'
+__version__ = '2.1.0'
 
+from .account import *
 from .aes import *
 from .api import FortniteAPI
 from .cosmetics import *
@@ -9,4 +10,4 @@ from .enums import *
 from .errors import *
 from .news import *
 from .shop import *
-from .user import *
+from .stats import *
